@@ -27,13 +27,16 @@ package Text::CSV::Base;
 #    
 # Version 0.10	2018-09-21
 #     Thin wrapper around Text::CSV
+#     
+# Version 0.20	2018-09-25
+#     Not used by Text::CSV::Unicode v0.300 
 ################################################################################
 
 use strict;
 use warnings;
 use base qw(Text::CSV);
 
-our $VERSION = '0.10';
+our $VERSION = '0.20';
 
 sub new { 
     my($self, $hash) = @_;
@@ -56,10 +59,12 @@ Text::CSV::Base - comma-separated values manipulation routines
 
 =head1 DESCRIPTION
 
-The same functionality as Text::CSV but set C<always_quote => 1>.
+The same functionality as Text::CSV with C<always_quote => 1>.
 
-This module exists to support Text::CSV::Unicode, 
-which assumes C<always_quote => 1> in its functionality.
+This module existed to support Text::CSV::Unicode (< v0.300), 
+which assumed C<always_quote => 1> in its functionality.
+
+This module is now redundant.
 
 =head1 FUNCTIONS
 
@@ -69,8 +74,9 @@ which assumes C<always_quote => 1> in its functionality.
 
  $csv = Text::CSV::Base->new();
 
-This function may be called as a class or an object method.  It returns a reference to a
-newly created Text::CSV::Base object.
+Create a new Text::CSV::Base object.
+
+This function may be called as a class or an object method.
 
 =back
 
